const { ModuleFederationPlugin } = require("webpack").container;

const path = require("path");

const DEFAULT_CWC_PUBLIC_URL = "http://localhost:3002"
const DEFAULT_CWC_PORT = 3002

const cwcPublicUrl = process.env.CWC_PUBLIC_URL || DEFAULT_CWC_PUBLIC_URL

let parsedCwcPort = null
if (process.env.CWC_PORT) {
  parsedCwcPort = Number(process.env.CWC_PORT)
  if (!parsedCwcPort) {
    console.error("The CWC_PORT must be a valid port number")
  }
}
const cwcPort = parsedCwcPort || DEFAULT_CWC_PORT

console.log("(cwc) CWC public URL:", cwcPublicUrl)
console.log("(cwc) CWC port (dev only):", cwcPort)

module.exports = {
  entry: "./src/define-all-elements.js",
  output: {
    filename: "web-components.js",
    path: path.resolve(__dirname, "./dist"),
    publicPath: cwcPublicUrl + '/',
  },
  mode: "development",
  devServer: {
    port: cwcPort,
    static: {
      directory: path.resolve(__dirname, "./dist"),
    },
    devMiddleware: {
      writeToDisk: true,
    },
  },
  module: {
    rules: [
      {
        test: /\.(png|svg|jpg|jpeg|gif)$/i,
        type: "asset",
        parser: {
          dataUrlCondition: {
            maxSize: 3 * 1024, // < 3 Kilobytes will be inlined
          },
        },
      },
      {
        test: /\.(html|css)$/,
        type: "asset/source",
      },
    ],
  },
  plugins: [
    new ModuleFederationPlugin({
      name: "Midnight",
      filename: "remoteEntry.js",
      exposes: {
        "./all-elements": "./src/define-all-elements.js",
        "./checkbox-icon": "./src/define-checkbox-icon-element.js",
        "./levels": "./src/define-levels-element.js",
        "./login": "./src/define-login-element.js",
        "./multiselect": "./src/define-multiselect-element.js",
        "./stepper": "./src/define-stepper-element.js",
        "./stepper-item": "./src/define-stepper-item-element.js",
        "./stepper-json": "./src/define-stepper-json-element.js",
        "./modal": './src/define-modal-element.js',
        "./month-picker": './src/define-monthPicker-element.js',
        "./flipcard": "./src/define-flipcard-element.js",
        "./textfield": "./src/define-textfield-element.js",
				 "./test181": "./src/define-test181-element.js",
				 "./test29": "./src/define-test29-element.js",
				 "./componentito": "./src/define-componentito-element.js",
				 "./test123": "./src/define-test123-element.js",
				 "./uncomponentenuevp": "./src/define-uncomponentenuevp-element.js",
				 "./componenttest": "./src/define-componenttest-element.js",
				 "./component123": "./src/define-component123-element.js",
				 "./test12344": "./src/define-test12344-element.js",
				 "./test002": "./src/define-test002-element.js",
				 "./onemoretime": "./src/define-onemoretime-element.js",
				 "./angularTest": "./src/define-angularTest-element.js",
				//END EXPOSES - DO NOT REMOVE THIS LINE
      },
    }),
  ],
};