import fs from 'fs';
import { createSpinner } from 'nanospinner';

async function createWebComponentFiles(name, config) {
    let htmlFile = `${config.webcomponents}/src/${name}/${name}.html`;
    let cssFile = `${config.webcomponents}/src/${name}/${name}.css`;
    let jsFile = `${config.webcomponents}/src/${name}/${name}.js`;

    const htmlSpinner = createSpinner('Creating html file... \n').start();

    fs.writeFile(htmlFile, `
    <div>
    ${name} works! 
    </div>`, function (err) {
        if (err) { htmlSpinner.error(); process.exit(1) };
        htmlSpinner.success();
    });

    const cssSpinner = createSpinner('Creating css file... \n').start();
    fs.writeFile(cssFile, "", function (err) {
        if (err) { cssSpinner.error(); process.exit(1) };
        cssSpinner.success();
    });

    const jsSpinner = createSpinner('Creating js file... \n').start();
    fs.writeFile(jsFile, `import html from './${name}.html';
    import css from './${name}.css';
    
    import { generateHTMLelementInnerHTML } from "../utils";
    
    export class Cwc${name} extends HTMLElement {
      constructor() {
        super();
        this.attachShadow({ mode: 'open'});
        this.shadowRoot.innerHTML = generateHTMLelementInnerHTML( css, html );
      }
    }`, function (err) {
        if (err) { jsSpinner.error(); process.exit(1) };
        jsSpinner.success();
    });


}

export default createWebComponentFiles;